@@ -3,12 +3,14 @@ mod use_before_unload;
 mod use_counter;
 mod use_effect_once;
 mod use_event;
+mod use_hash;
 mod use_interval;
 mod use_is_first_mount;
 mod use_is_mounted;
 mod use_latest;
 mod use_list;
 mod use_local_storage;
+mod use_location;
 mod use_map;
 mod use_mount;
 mod use_previous;
@@ -17,6 +19,7 @@ mod use_raf;
 mod use_raf_state;
 mod use_scroll;
 mod use_scrolling;
+mod use_search_param;
 mod use_session_storage;
 mod use_set;
 mod use_timeout;
@@ -32,12 +35,14 @@ pub use use_before_unload::*;
 pub use use_counter::*;
 pub use use_effect_once::*;
 pub use use_event::*;
+pub use use_hash::*;
 pub use use_interval::*;
 pub use use_is_first_mount::*;
 pub use use_is_mounted::*;
 pub use use_latest::*;
 pub use use_list::*;
 pub use use_local_storage::*;
+pub use use_location::*;
 pub use use_map::*;
 pub use use_mount::*;
 pub use use_previous::*;
@@ -46,6 +51,7 @@ pub use use_raf::*;
 pub use use_raf_state::*;
 pub use use_scroll::*;
 pub use use_scrolling::*;
+pub use use_search_param::*;
 pub use use_session_storage::*;
 pub use use_set::*;
 pub use use_timeout::*;
